The model includes the presence-only data, all selected variables, the link functions for \(q\) and \(p\), the initial values and the prior distribution.
# S4 method for bayesPO_model
names(x)# S4 method for bayesPO_model
$(x, name)
# S4 method for bayesPO_model
$(x, name) <- value
# S4 method for bayesPO_model
show(object)
# S4 method for bayesPO_model
print(x, ...)
# S3 method for bayesPO_model
print(x, ...)
names: A character vector with possible options
for the `$` and `$<-` methods.
`$`: The requested slot's value.
`$<-`: The new object with the updated slot.
show and print: The invisible object.
The bayesPO_model object.
The requested slot.
New value.
The bayesPO_model object.
Currently unused.
poThe matrix containing the covariates values for the data.
intensityLinkA string informing about the chosen link for the
intensity covariates. Current acceptable choice is only "logit".
intensitySelectionA vector containing the indexes of the selected
intensity columns in the po matrix.
observabilityLinkA string informing about the chosen link for the
observability covariates. Current acceptable choice is only "logit".
observabilitySelectionA vector containing the indexes of the selected
observability columns in the po matrix.
initA list with objects of class bayesPO_initial indicating
the initial values for each chain. The length of this list tells the program
how many chains are requested to be run.
priorAn object of class bayesPO_prior which indicates the
joint prior distribution for the model parameters.
iSelectedColumnsIf the intensity covariates selection was made with the name of the columns, they are stored in this slot.
oSelectedColumnsIf the observability covariates selection was made with the name of the columns, they are stored in this slot.
bayesPO_initial-class and
bayesPO_prior-class and bayesPO_model