Learn R Programming

bayesPO (version 0.5.0)

bayesPO_prior-class: Joint prior class for the bayesPO package parameters

Description

Objects of this class are the joining of independent priors for Beta, Delta and LambdaStar. They can be used in the fit_bayesPO function.

Usage

# S4 method for bayesPO_prior
names(x)

# S4 method for bayesPO_prior $(x, name)

# S4 method for bayesPO_prior show(object)

# S4 method for bayesPO_prior print(x, ...)

# S3 method for bayesPO_prior print(x, ...)

# S4 method for bayesPO_prior $(x, name)

# S4 method for bayesPO_prior $(x, name) <- value

Value

names: A character vector with the model parameters names.

`$`: The requested slot's value.

`$<-`: The new object with the updated slot.

Arguments

x

The bayesPO_prior object.

name

The requested slot.

object

The bayesPO_prior object.

...

Ignored.

value

New value.

Fields

beta

An object of a class which inherits the BetaDeltaPrior S4 class with the appropriate Beta prior.

delta

An object of a class which inherits the BetaDeltaPrior S4 class with the appropriate Delta prior.

lambdaStar

An object of a class which inherits the LambdaStarPrior S4 class with the appropriate LambdaStar prior.